@@ -80,7 +80,7 @@ struct _AtkRoleItem
 static AtkRoleItem role_items [] =
 {
   { ATK_ROLE_INVALID, N_("invalid")},
-  { ATK_ROLE_ACCEL_LABEL, N_("accel label")},
+  { ATK_ROLE_ACCEL_LABEL, N_("accelerator label")},
   { ATK_ROLE_ALERT, N_("alert")},
   { ATK_ROLE_ANIMATION, N_("animation")},
   { ATK_ROLE_ARROW, N_("arrow")},
@@ -398,7 +398,7 @@ atk_object_class_init (AtkObjectClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_HYPERTEXT_NUM_LINKS,
                                    g_param_spec_int    (atk_object_name_property_hypertext_num_links,
-                                                        _("Accessible Hypertext Number of Links"),
+                                                        _("Number of Accessible Hypertext Links"),
                                                         _("The number of links which the current AtkHypertext has"),
                                                         0,
                                                         G_MAXINT,
@@ -1285,9 +1285,9 @@ atk_role_get_name (AtkRole role)
 
 #ifdef G_OS_WIN32
 
-#undef ATKLOCALEDIR
+#undef ATK_LOCALEDIR
 
-#define ATKLOCALEDIR get_atk_locale_dir()
+#define ATK_LOCALEDIR get_atk_locale_dir()
 
 G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
 
@@ -1320,7 +1320,7 @@ atk_role_get_localized_name (AtkRole role)
     {
       gettext_initialized = TRUE;
 
-      bindtextdomain (GETTEXT_PACKAGE, ATKLOCALEDIR);
+      bindtextdomain (GETTEXT_PACKAGE, ATK_LOCALEDIR);
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
       bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
